@@ -91,6 +91,7 @@ table_crc_lo = (
 # >	            大端	            标准	        none,按原字节数
 # !	            network(大端)	标准	        none,按原字节数
 
+# region 显示功能
 # 数组转16进制字符串
 def bytes_to_hex_str(bs):
     """ 数组转16进制字符串
@@ -115,6 +116,8 @@ def hex_str_to_bytes(str_data):
         print(e)
 
 
+# endregion
+# region 从数组获取数据
 # 从bytes获取int8
 def get_int8_from_bytes(bytes_data, index=0):
     """ 从bytes获取int8
@@ -225,37 +228,6 @@ def get_uint32_from_bytes(bytes_data, index=0, order=""):
         print(e)
 
 
-# 从bytes获取指定格式数据
-def get_data_from_bytes(bytes_data, type="", index=0, order=""):
-    """ 从bytes获取指定格式数据
-    :param1 bytes_data: 所要读取的数组，bytes、bytearray、list类型
-    :param2 type: 所要读取的数据格式，默认为“”，需输入字符串：int8、uint8、int16、uint16、int32、uint32、float、double，不区分大小写
-    :param3 index: 所要读取的索引位置，默认为0
-    :param4 order: 大小端，默认为小端，输入"big"或”little“
-    :return: 对应值
-    """
-    if type.lower() == "":
-        print("miss input: type")
-        return None
-    elif type.lower() == "int8":
-        return get_int8_from_bytes(bytes_data, index)
-    elif type.lower() == "uint8":
-        return get_uint8_from_bytes(bytes_data, index)
-    elif type.lower() == "int16":
-        return get_int16_from_bytes(bytes_data, index, order)
-    elif type.lower() == "uint16":
-        return get_uint16_from_bytes(bytes_data, index, order)
-    elif type.lower() == "int32":
-        return get_int32_from_bytes(bytes_data, index, order)
-    elif type.lower() == "float":
-        return get_float_from_bytes(bytes_data, index, order)
-    elif type.lower() == "double":
-        return get_double_from_bytes(bytes_data, index, order)
-    else:
-        print("error input: type")
-        return None
-
-
 # 从bytes获取float
 def get_float_from_bytes(bytes_data, index=0, order=""):
     """ 从bytes获取float
@@ -298,6 +270,39 @@ def get_double_from_bytes(bytes_data, index=0, order=""):
         print(e)
 
 
+# 从bytes获取指定格式数据
+def get_data_from_bytes(bytes_data, type="", index=0, order=""):
+    """ 从bytes获取指定格式数据
+    :param1 bytes_data: 所要读取的数组，bytes、bytearray、list类型
+    :param2 type: 所要读取的数据格式，默认为“”，需输入字符串：int8、uint8、int16、uint16、int32、uint32、float、double，不区分大小写
+    :param3 index: 所要读取的索引位置，默认为0
+    :param4 order: 大小端，默认为小端，输入"big"或”little“
+    :return: 对应值
+    """
+    if type.lower() == "":
+        print("miss input: type")
+        return None
+    elif type.lower() == "int8":
+        return get_int8_from_bytes(bytes_data, index)
+    elif type.lower() == "uint8":
+        return get_uint8_from_bytes(bytes_data, index)
+    elif type.lower() == "int16":
+        return get_int16_from_bytes(bytes_data, index, order)
+    elif type.lower() == "uint16":
+        return get_uint16_from_bytes(bytes_data, index, order)
+    elif type.lower() == "int32":
+        return get_int32_from_bytes(bytes_data, index, order)
+    elif type.lower() == "float":
+        return get_float_from_bytes(bytes_data, index, order)
+    elif type.lower() == "double":
+        return get_double_from_bytes(bytes_data, index, order)
+    else:
+        print("error input: type")
+        return None
+
+
+# endregion
+# region 将数据加入数组
 # 加入int8至bytes
 def add_int8_to_bytes(bytes_data, value, index=None):
     """ 加入int8至bytes
@@ -544,6 +549,8 @@ def add_double_to_bytes(bytes_data, value, index=None, order=""):
         return bytes_data
 
 
+# endregion
+# region 将数据转换数组
 # 获得int8对应bytearray
 def get_int8_bytes(value):
     """ 获得int8对应bytearray
@@ -724,6 +731,8 @@ def get_double_bytes(value, order=""):
         return
 
 
+# endregion
+# region crc16_modbus功能
 # bytes加入crc16_modbus
 def bytes_add_crc16_modbus(bytes_data, start_index=0, front=""):
     """ bytes加入crc16_modbus
@@ -736,11 +745,11 @@ def bytes_add_crc16_modbus(bytes_data, start_index=0, front=""):
         bytes_data = bytearray(bytes_data)
     temp = crc16_modbus_bytes(bytes_data, start_index)
     if (front is "") or (front.lower() == "low"):
-        bytes_data.append(temp[1])
         bytes_data.append(temp[0])
+        bytes_data.append(temp[1])
     elif front.lower() == "high":
-        bytes_data.append(temp[0])
         bytes_data.append(temp[1])
+        bytes_data.append(temp[0])
     else:
         print("front is not low or high")
         return
@@ -760,8 +769,30 @@ def crc16_modbus_int16(bytes_data, start_index=0):
         crc_hi = crc_lo ^ table_crc_hi[i]
         crc_lo = table_crc_lo[i]
     result = crc_hi << 8 | crc_lo
+    print([crc_hi, crc_lo])
     return result
 
+
+# crc16_modbus返回[crc_L,crc_H]
+def crc16_modbus_bytes(bytes_data, start_index=0):
+    """ bytes加入crc16_modbus
+    :param1 bytes_data: 所需加入CRC校验码的数组，bytes、bytearray、list类型
+    :param2 start_index: 所需计算CRC校验码的开始索引，默认为0
+    :return: CRC16数值 bytearray结果[crc_L,crc_H]
+    """
+    crc_hi = crc_lo = 0xFF
+    for ch in bytes_data[start_index:]:
+        i = crc_hi ^ ch
+        crc_hi = crc_lo ^ table_crc_hi[i]
+        crc_lo = table_crc_lo[i]
+    result = bytearray()
+    result.append(crc_hi)
+    result.append(crc_lo)
+    return result
+
+
+# endregion
+# region 其他功能
 # 返回帧头
 def find_head(bytes_data, head_data):
     """ bytes加入crc16_modbus
@@ -784,26 +815,15 @@ def find_head(bytes_data, head_data):
         return None
 
 
-# crc16_modbus返回[crc_H,crc_L]
-def crc16_modbus_bytes(bytes_data, start_index=0):
-    """ bytes加入crc16_modbus
-    :param1 bytes_data: 所需加入CRC校验码的数组，bytes、bytearray、list类型
-    :param2 start_index: 所需计算CRC校验码的开始索引，默认为0
-    :return: CRC16数值 bytearray结果[crc_H,crc_L]
-    """
-    crc_hi = crc_lo = 0xFF
-    for ch in bytes_data[start_index:]:
-        i = crc_hi ^ ch
-        crc_hi = crc_lo ^ table_crc_hi[i]
-        crc_lo = table_crc_lo[i]
-    result = bytearray()
-    result.append(crc_hi)
-    result.append(crc_lo)
-    return result
-
+# endregion
 
+# 测试代码
 if __name__ == '__main__':
-    input_data = [0xAA, 0x55, 0x01, 0x02, 0x00, 0x00, 0xAA, 0x55, 0x01]
-    index = find_head(input_data, [0x01, 0x03])
-    print(bytes_to_hex_str(get_int32_bytes(-200)))
+    input_data = [0x01, 0x03, 0x00, 0x01, 0x00, 0x01]
+    print("*" * 50)
+    print(bytes_to_hex_str(input_data))
+    print(bytes_to_hex_str(crc16_modbus_bytes(input_data)))
+    print(crc16_modbus_int16(input_data))
+    print("*" * 50)
+    print(bytes_to_hex_str(bytes_add_crc16_modbus(input_data, front="low")))
     pass
